Fruit enum
Fruit is used in tests and demos.
Values
- apple → const Fruit
- apricot → const Fruit
- banana → const Fruit
- blackberry → const Fruit
- cantaloupe → const Fruit
- coconut → const Fruit
- cranberry → const Fruit
- date → const Fruit
- durian → const Fruit
- elderberry → const Fruit
- fig → const Fruit
- grapefruit → const Fruit
- guava → const Fruit
- jackfruit → const Fruit
- kiwi → const Fruit
- lemon → const Fruit
- lime → const Fruit
- longan → const Fruit
- loquat → const Fruit
- lychee → const Fruit
- mango → const Fruit
- nectarine → const Fruit
- orange → const Fruit
- peach → const Fruit
- pear → const Fruit
- pineapple → const Fruit
- prune → const Fruit
- raspberry → const Fruit
- strawberry → const Fruit
- watermelon → const Fruit
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited